# DjangoHeads

---

**Documentation**: coming soon

**Source Code**: <a href="https://github.com/djangoheads/djangoheads" target="_blank">
https://github.com/djangoheads/djangoheads
</a>

---

Djangoheads is a comprehensive project that includes the most efficient and user-friendly tools for Django development.

## Installation

Tested on CPython 3.8, 3.9, 3.10, 3.11 and 3.12.

```shell
pip install djangoheads
```
